api.system.components.configuration.v1 package — Argus-Toolbelt 1.0 documentation

# api.system.components.configuration.v1 package

## Submodules

## api.system.components.configuration.v1.host module

Autogenerated API

`api.system.components.configuration.v1.host.` `add_comment`(id: int, body: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add a comment to configuration host (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of host to comment body (`str`) – Comment
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 953, “limit”: 921, “responseCode”: 200, “count”: 824, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Member civil material decade bill.”, “messageTemplate”: “Try not crime rule always apply.”, “field”: “Opportunity spend civil.”, “parameter”: {}, “timestamp”: 1088999593}], “currentPage”: 533, “size”: 939}

`api.system.components.configuration.v1.host.` `create`(name: str = None, information: str = None, properties: dict = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Create new configuration host (INTERNAL)

  Return type: | `dict`
  Parameters: | name (str) – [a-zA-Z0-9_-.]* information (str) – [sw{}$-().[]“‘_/,*+#:@!?;]* properties (dict) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 252, “limit”: 353, “responseCode”: 200, “count”: 709, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Necessary save until side allow interest.”, “messageTemplate”: “Moment control maintain grow build consumer amount see.”, “field”: “Certainly soldier painting attack.”, “parameter”: {}, “timestamp”: 78767406}], “currentPage”: 204, “size”: 545}

`api.system.components.configuration.v1.host.` `delete`(id: int, deleteInstances: bool = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete configuration host (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of host to delete deleteInstances (bool) – If true, force deletion of instances for this host first
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 609, “limit”: 339, “responseCode”: 200, “count”: 104, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Structure public trade cause discussion report coach go.”, “messageTemplate”: “Political south its exactly.”, “field”: “Happen exist do defense situation.”, “parameter”: {}, “timestamp”: 475892699}], “currentPage”: 510, “size”: 458}

`api.system.components.configuration.v1.host.` `disable_monitoring`(id: int, comment: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Disable monitoring of configuration host (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of host to disable monitoring on comment (str) – Reason for disabling monitoring
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 62, “limit”: 711, “responseCode”: 200, “count”: 555, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Lot word win perhaps late drop.”, “messageTemplate”: “Least discussion crime west along.”, “field”: “Present side necessary hand population.”, “parameter”: {}, “timestamp”: 229135525}], “currentPage”: 330, “size”: 594}

`api.system.components.configuration.v1.host.` `duplicate`(hostID: int, packagename: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Create default instances on configuration host (INTERNAL)

  Return type: | `dict`
  Parameters: | hostID (int) – ID of host to add instances to packagename (str) – Instance package names
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {}

`api.system.components.configuration.v1.host.` `enable_monitoring`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Enable monitoring of configuration host (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of host to enable monitoring on
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 532, “limit”: 350, “responseCode”: 200, “count”: 783, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Much car military.”, “messageTemplate”: “Professional company he forget once door pattern.”, “field”: “Whom watch local take than everybody step.”, “parameter”: {}, “timestamp”: 606029131}], “currentPage”: 462, “size”: 717}

`api.system.components.configuration.v1.host.` `list`(search: str = None, orderDesc: bool = None, includeComments: bool = 'True', includeDeleted: bool = 'True', offset: int = 0, limit: int = 25, orderBy: str = 'name', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List configuration hosts (INTERNAL)

  Return type: | `dict`
  Parameters: | search (str) – Limit results to hosts matching this searchstring orderDesc (bool) – Sort results descending includeComments (bool) – Include comments in output includeDeleted (bool) – Include deleted hosts in results offset (int) – Offset results limit (int) – Limit results orderBy (str) – Sort results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 285, “limit”: 779, “responseCode”: 200, “count”: 136, “data”: [{“id”: 295, “name”: “Michelle Morgan”, “flags”: 240, “scheduledDowntimeFrom”: 67, “scheduledDowntimeTo”: 637, “created”: 219, “lastUpdatedTimestamp”: 829694226, “lastUpdatedByUser”: {“id”: 639, “customerID”: 492, “userName”: “patriciahernandez”, “name”: “Rebecca Martinez”}, “information”: “Truth miss employee condition role.”, “comments”: [{“timestamp”: 1425741093, “comment”: “Scene performance various turn.”}], “properties”: {“additionalProperties”: “Pull pretty feeling crime develop seek community back.”}}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Yes officer natural strategy imagine firm.”, “messageTemplate”: “Or skill they side.”, “field”: “Line against card represent represent trouble.”, “parameter”: {}, “timestamp”: 1040876555}], “currentPage”: 917, “size”: 244}

`api.system.components.configuration.v1.host.` `schedule_monitoring`(id: int, _from: int = None, to: int = None, comment: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Schedule downtime for configuration host (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of host to schedule downtime for from (int) – Timestamp to schedule downtime from to (int) – Timestamp to schedule downtime to comment (str) – Reason for scheduling downtime
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 270, “limit”: 949, “responseCode”: 200, “count”: 240, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Help near while human once have.”, “messageTemplate”: “System authority memory discussion.”, “field”: “Others tree southern history federal citizen.”, “parameter”: {}, “timestamp”: 1334121667}], “currentPage”: 18, “size”: 12}

`api.system.components.configuration.v1.host.` `search`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: <function list at 0x1112926a8> = None, searchString: str = None, sortBy: <function list at 0x1112926a8> = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeComments: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search configuration hosts (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – searchString (str) – sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeComments (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 928, “limit”: 502, “responseCode”: 200, “count”: 652, “data”: [{“id”: 421, “name”: “Cody Oneill”, “flags”: 155, “scheduledDowntimeFrom”: 955, “scheduledDowntimeTo”: 346, “created”: 678, “lastUpdatedTimestamp”: 1052364224, “lastUpdatedByUser”: {“id”: 514, “customerID”: 615, “userName”: “xbarry”, “name”: “Natasha Thornton”}, “information”: “Star blue outside during.”, “comments”: [{“timestamp”: 312656843, “comment”: “Brother let member us same south.”}], “properties”: {“additionalProperties”: “Force pattern clearly must past suffer.”}}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Factor interview great mother collection power.”, “messageTemplate”: “Movie purpose together behavior religious rather challenge.”, “field”: “Consumer member like your her.”, “parameter”: {}, “timestamp”: 215913225}], “currentPage”: 450, “size”: 424}

`api.system.components.configuration.v1.host.` `update`(hostID: int, id: int = None, name: str = None, information: str = None, properties: dict = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update configuration host (INTERNAL)

  Return type: | `dict`
  Parameters: | hostID (int) – ID of host to update id (int) – name (str) – [a-zA-Z0-9_-.]* information (str) – [sw{}$-().[]“‘_/,*+#:@!?;]* properties (dict) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 345, “limit”: 845, “responseCode”: 200, “count”: 787, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Book tonight artist share reality.”, “messageTemplate”: “Successful management close radio be life discuss.”, “field”: “Court country last read big degree bag.”, “parameter”: {}, “timestamp”: 190640983}], “currentPage”: 327, “size”: 617}

`api.system.components.configuration.v1.host.` `view`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch configuration host (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of host to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 373, “limit”: 194, “responseCode”: 200, “count”: 518, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Help exist spend dinner.”, “messageTemplate”: “Study art dinner we suggest.”, “field”: “Yes ago answer protect clear.”, “parameter”: {}, “timestamp”: 1430475026}], “currentPage”: 115, “size”: 557}

## api.system.components.configuration.v1.instance module

Autogenerated API

`api.system.components.configuration.v1.instance.` `add_comment`(id: int, body: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add a comment to configuration instance (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of instance to comment body (`str`) – Comment
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 902, “limit”: 188, “responseCode”: 200, “count”: 842, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Admit eat last early organization seven.”, “messageTemplate”: “Author six recently develop.”, “field”: “Focus it environment sister.”, “parameter”: {}, “timestamp”: 641881065}], “currentPage”: 491, “size”: 759}

`api.system.components.configuration.v1.instance.` `create`(templateID: int = None, hostID: int = None, parentID: int = None, information: str = None, properties: dict = None, identifiers: dict = None, codeProfile: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Create new configuration instance (INTERNAL)

  Return type: | `dict`
  Parameters: | templateID (int) – hostID (int) – parentID (int) – information (str) – [sw{}$-().[]“‘_/,*+#:@!?;]* properties (dict) – identifiers (dict) – codeProfile (str) – [a-zA-Z0-9_-.]*
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 874, “limit”: 752, “responseCode”: 200, “count”: 350, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Lose home politics production oil phone field.”, “messageTemplate”: “Thus create by television within daughter south.”, “field”: “Star card same onto others must what wife.”, “parameter”: {}, “timestamp”: 1141697788}], “currentPage”: 992, “size”: 410}

`api.system.components.configuration.v1.instance.` `delete`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete configuration instance (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of instance to delete
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 766, “limit”: 543, “responseCode”: 200, “count”: 19, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Evening why top the cut miss radio.”, “messageTemplate”: “Range put between.”, “field”: “Party provide defense cover hotel common fly.”, “parameter”: {}, “timestamp”: 874119028}], “currentPage”: 885, “size”: 86}

`api.system.components.configuration.v1.instance.` `disable_monitoring`(id: int, comment: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Disable monitoring of configuration instance (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of instance to disable monitoring on comment (str) – Reason for disabling monitoring
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 189, “limit”: 857, “responseCode”: 200, “count”: 234, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Task small quite six sense tell.”, “messageTemplate”: “Seem affect perhaps resource career cup even.”, “field”: “Here amount too church painting detail.”, “parameter”: {}, “timestamp”: 291600892}], “currentPage”: 416, “size”: 465}

`api.system.components.configuration.v1.instance.` `enable_monitoring`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Enable monitoring of configuration instance (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of instance to enable monitoring on
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 702, “limit”: 242, “responseCode”: 200, “count”: 979, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Voice camera son figure son investment possible eye.”, “messageTemplate”: “Activity benefit risk although.”, “field”: “Past maybe turn until mouth.”, “parameter”: {}, “timestamp”: 1470624119}], “currentPage”: 47, “size”: 593}

`api.system.components.configuration.v1.instance.` `list`(offset: int = None, search: str = None, includeComments: bool = None, includeDeleted: bool = None, templateID: list = None, hostID: list = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List configuration instances (INTERNAL)

  Return type: | `dict`
  Parameters: | offset (int) – Offset results search (str) – Limit results to instances matching this searchstring includeComments (bool) – Include comments in output includeDeleted (bool) – Include deleted instances templateID (list) – Limit results to instances with these templates hostID (list) – Limit results to instances on these hosts limit (int) – Limit results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 116, “limit”: 242, “responseCode”: 200, “count”: 444, “data”: [{“id”: 467, “flags”: 483, “scheduledDowntimeFrom”: 117, “scheduledDowntimeTo”: 528, “revision”: 272, “masterID”: 236, “createdTimestamp”: 734890267, “lastUpdatedTimestamp”: 306868714, “lastUpdatedByUser”: {“id”: 398, “customerID”: 269, “userName”: “mali”, “name”: “Lauren Smith”}, “information”: “Whom represent talk hotel source fact boy later.”, “properties”: {“additionalProperties”: “Relationship similar raise talk should simple tough have.”}, “identifiers”: {“additionalProperties”: “Week store whatever in attention although.”}, “comments”: [{“timestamp”: 1368073583, “comment”: “With must explain art throughout.”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Some benefit boy.”, “messageTemplate”: “Live effect step condition feeling line.”, “field”: “Training what suffer deep force policy firm.”, “parameter”: {}, “timestamp”: 1068332432}], “currentPage”: 886, “size”: 515}

`api.system.components.configuration.v1.instance.` `revisions`(id: int, offset: int = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List configuration instance revisions (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of instance to fetch revisions for offset (int) – Offset results limit (int) – Limit results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 85, “limit”: 405, “responseCode”: 200, “count”: 890, “data”: [{“id”: 390, “flags”: 699, “scheduledDowntimeFrom”: 292, “scheduledDowntimeTo”: 680, “revision”: 949, “masterID”: 426, “createdTimestamp”: 1374245049, “lastUpdatedTimestamp”: 1233901334, “lastUpdatedByUser”: {“id”: 892, “customerID”: 102, “userName”: “billycain”, “name”: “Monica Wilson”}, “information”: “Risk glass to since social.”, “properties”: {“additionalProperties”: “Operation federal manager grow method enjoy her.”}, “identifiers”: {“additionalProperties”: “Save seek natural a strategy number.”}, “comments”: [{“timestamp”: 1228921326, “comment”: “Coach can outside design between growth baby.”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Either whom owner manager.”, “messageTemplate”: “Fear bar seek new yeah would prevent.”, “field”: “Sound rich marriage from station.”, “parameter”: {}, “timestamp”: 509074585}], “currentPage”: 54, “size”: 728}

`api.system.components.configuration.v1.instance.` `schedule_monitoring`(id: int, _from: int = None, to: int = None, comment: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Schedule downtime for configuration instance (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of instance to schedule downtime for from (int) – Timestamp to schedule downtime from to (int) – Timestamp to schedule downtime to comment (str) – Reason for scheduling downtime
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 581, “limit”: 976, “responseCode”: 200, “count”: 728, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Education scientist real unit.”, “messageTemplate”: “Large something plan design something apply thousand growth.”, “field”: “Thousand increase conference reduce letter option.”, “parameter”: {}, “timestamp”: 1249157359}], “currentPage”: 299, “size”: 702}

`api.system.components.configuration.v1.instance.` `search`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: <function list at 0x111b0a510> = None, templateID: <function list at 0x111b0a510> = None, hostID: <function list at 0x111b0a510> = None, parentID: <function list at 0x111b0a510> = None, codeProfile: <function list at 0x111b0a510> = None, keywords: <function list at 0x111b0a510> = None, masterID: int = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeComments: bool = 'False', codeProfileOverride: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search configuration instances (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – templateID (list) – If set, filter instances by template ID. hostID (list) – If set, filter instances by host ID. parentID (list) – If set, filter instances by parent instance ID. codeProfile (list) – If set, filter instances by active code profile. keywords (list) – If set, filter instances where host or template name matches these keywords. masterID (int) – If set, only include instance revisions of given master. If not set, revisions are excluded. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeComments (bool) – If true, include comments in output. codeProfileOverride (bool) – If true, only return instances with overridden code profile. If false, exclude. If not set, do not filter.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 217, “limit”: 79, “responseCode”: 200, “count”: 672, “data”: [{“id”: 966, “flags”: 218, “scheduledDowntimeFrom”: 173, “scheduledDowntimeTo”: 155, “revision”: 503, “masterID”: 114, “createdTimestamp”: 1221967439, “lastUpdatedTimestamp”: 181715212, “lastUpdatedByUser”: {“id”: 643, “customerID”: 459, “userName”: “pittsbrian”, “name”: “Rebecca Garcia”}, “information”: “Law too operation real accept.”, “properties”: {“additionalProperties”: “Quickly yeah draw method star country major the.”}, “identifiers”: {“additionalProperties”: “Because anyone area shoulder source international.”}, “comments”: [{“timestamp”: 419075077, “comment”: “Technology send various.”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Local fact speak particular.”, “messageTemplate”: “Ten another child watch white at.”, “field”: “Public heavy risk develop red.”, “parameter”: {}, “timestamp”: 1138545973}], “currentPage”: 881, “size”: 339}

`api.system.components.configuration.v1.instance.` `update`(id: int, configurationID: int = None, hostID: int = None, parentID: int = None, information: str = None, properties: dict = None, identifiers: dict = None, codeProfile: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update configuration instance (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of instance to update configurationID (int) – hostID (int) – If set, assign instance to given configuration host. parentID (int) – If set, set parent instance for this instance (on same configuration host). information (str) – If set, change information field for instance. => [sw{}$-().[]“‘_/,*+#:@!?;]* properties (dict) – If set, set these properties for instance. Property with null value will delete existing property. identifiers (dict) – If set, set these identifiers for instance. Identifier with null value will delete existing identifier. codeProfile (str) – Name of code profile to use. If null, do not change. If blank, reset to template profile. => [a-zA-Z0-9_-.]*
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 288, “limit”: 652, “responseCode”: 200, “count”: 937, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Shoulder certain moment international leave still time.”, “messageTemplate”: “About so watch into argue carry.”, “field”: “Material let clearly show care road body.”, “parameter”: {}, “timestamp”: 435256290}], “currentPage”: 236, “size”: 608}

`api.system.components.configuration.v1.instance.` `view`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch configuration instance (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of instance to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 147, “limit”: 682, “responseCode”: 200, “count”: 493, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Thousand individual necessary participant.”, “messageTemplate”: “Else discussion loss.”, “field”: “Hospital measure series movie class attack.”, “parameter”: {}, “timestamp”: 1125161184}], “currentPage”: 315, “size”: 836}

## api.system.components.configuration.v1.template module

Autogenerated API

`api.system.components.configuration.v1.template.` `add_comment`(id: int, body: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add a comment to a configuration template (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of template to add comment to body (`str`) – Comment
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 915, “limit”: 377, “responseCode”: 200, “count”: 989, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Third might high reduce.”, “messageTemplate”: “Over thank drop.”, “field”: “Small rise good evening itself activity.”, “parameter”: {}, “timestamp”: 1068458354}], “currentPage”: 465, “size”: 937}

`api.system.components.configuration.v1.template.` `create`(name: str = None, shortName: str = None, mnemonic: str = None, configuration: str = None, properties: dict = None, information: str = None, dependsOnID: int = None, codeProfile: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Create new configuration template (INTERNAL)

  Return type: | `dict`
  Parameters: | name (str) – [a-zA-Z0-9_-.]* shortName (str) – [a-zA-Z0-9_-.]* mnemonic (str) – [a-zA-Z0-9_-.]* configuration (str) – format:xml properties (dict) – information (str) – [sw{}$-().[]“‘_/,*+#:@!?;]* dependsOnID (int) – codeProfile (str) – [a-zA-Z0-9_-.]*
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 569, “limit”: 441, “responseCode”: 200, “count”: 191, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Attorney drug step behavior course leave.”, “messageTemplate”: “Test begin measure city town everybody throw glass.”, “field”: “Task body entire community film American.”, “parameter”: {}, “timestamp”: 342578577}], “currentPage”: 418, “size”: 418}

`api.system.components.configuration.v1.template.` `delete`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete configuration template (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of template to delete
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 863, “limit”: 718, “responseCode”: 200, “count”: 771, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Onto cause expert news region hot.”, “messageTemplate”: “Age meet see walk.”, “field”: “Cell class physical image any.”, “parameter”: {}, “timestamp”: 185856517}], “currentPage”: 760, “size”: 952}

`api.system.components.configuration.v1.template.` `duplicate`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Create a duplicate of a configuration template (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of template to duplicate
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 662, “limit”: 164, “responseCode”: 200, “count”: 22, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Scientist three exist thank view bill.”, “messageTemplate”: “Improve remain task.”, “field”: “Simply instead front clearly college forget.”, “parameter”: {}, “timestamp”: 1086888620}], “currentPage”: 455, “size”: 813}

`api.system.components.configuration.v1.template.` `list`(search: str = None, orderDesc: bool = None, includeComments: bool = 'True', includeDeleted: bool = 'True', offset: int = 0, limit: int = 25, orderBy: str = 'name', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List configuration templates (INTERNAL)

  Return type: | `dict`
  Parameters: | search (str) – orderDesc (bool) – Sort results descending includeComments (bool) – includeDeleted (bool) – offset (int) – limit (int) – orderBy (str) – Sort results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 549, “limit”: 461, “responseCode”: 200, “count”: 349, “data”: [{“id”: 507, “name”: “Jeffery Bell”, “mnemonic”: “Fast too available song real if.”, “shortName”: “You thank high issue behavior his six.”, “configurationData”: “Treat surface social six.”, “properties”: {“additionalProperties”: “For push activity girl go.”}, “flags”: 269, “revision”: 414, “masterID”: 320, “createdTimestamp”: 965656292, “lastUpdatedTimestamp”: 110671943, “lastUpdatedByUser”: {“id”: 533, “customerID”: 243, “userName”: “melaniejordan”, “name”: “Russell Keller”}, “information”: “Thought design north computer.”, “comments”: [{“timestamp”: 430344760, “comment”: “Dog place any fire.”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Future few less later long experience.”, “messageTemplate”: “Food maybe rather citizen present suggest.”, “field”: “Remain of reality join myself ago.”, “parameter”: {}, “timestamp”: 883110583}], “currentPage”: 412, “size”: 769}

`api.system.components.configuration.v1.template.` `revisions`(id: int, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List revisions of configuration template (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of template limit (int) – Max number of revisions to fetch
  Returns: | {“offset”: 678, “limit”: 889, “responseCode”: 200, “count”: 171, “data”: [{“id”: 222, “name”: “Tammy Bishop”, “mnemonic”: “Performance political doctor then always.”, “shortName”: “Blood woman why sound wait.”, “configurationData”: “Beautiful glass bar employee.”, “properties”: {“additionalProperties”: “Best say head.”}, “flags”: 429, “revision”: 453, “masterID”: 426, “createdTimestamp”: 531682624, “lastUpdatedTimestamp”: 943594106, “lastUpdatedByUser”: {“id”: 40, “customerID”: 339, “userName”: “jennifer12”, “name”: “Eric Miller”}, “information”: “Weight word information quite.”, “comments”: [{“timestamp”: 1075546513, “comment”: “One them democratic child.”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Public analysis least note.”, “messageTemplate”: “Weight exactly wide owner will whom.”, “field”: “Institution enter group knowledge talk really.”, “parameter”: {}, “timestamp”: 671695124}], “currentPage”: 785, “size”: 354}

`api.system.components.configuration.v1.template.` `search`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: <function list at 0x111ca07b8> = None, codeProfile: <function list at 0x111ca07b8> = None, keywords: <function list at 0x111ca07b8> = None, dependingOnID: <function list at 0x111ca07b8> = None, sortBy: <function list at 0x111ca07b8> = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeComments: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search configuration templates (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – codeProfile (list) – If true, filter on templates having any of these code profiles. keywords (list) – If true, filter on templates where name matches these keywords. dependingOnID (list) – If set, filter on templates set to depend on any of the given template IDs. sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeComments (bool) – If true, also include comments on output.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 727, “limit”: 691, “responseCode”: 200, “count”: 885, “data”: [{“id”: 113, “name”: “Elizabeth Mcmahon”, “mnemonic”: “World majority thought miss energy report.”, “shortName”: “Very case down risk.”, “configurationData”: “Before go than.”, “properties”: {“additionalProperties”: “Size dream strategy nation exactly.”}, “flags”: 327, “revision”: 946, “masterID”: 786, “createdTimestamp”: 848038798, “lastUpdatedTimestamp”: 367897776, “lastUpdatedByUser”: {“id”: 906, “customerID”: 418, “userName”: “arielwalker”, “name”: “Sherri Hopkins”}, “information”: “Structure explain benefit human truth adult option.”, “comments”: [{“timestamp”: 1262389358, “comment”: “Professor from politics century second show meet.”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Card instead station they.”, “messageTemplate”: “Technology answer fact tree easy.”, “field”: “Career eat lose surface.”, “parameter”: {}, “timestamp”: 382732151}], “currentPage”: 408, “size”: 210}

`api.system.components.configuration.v1.template.` `update`(id: int, name: str = None, mnemonic: str = None, shortName: str = None, configuration: str = None, properties: dict = None, information: str = None, dependsOnID: int = None, codeProfile: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update configuration template (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of template to update name (str) – [a-zA-Z0-9_-.]* mnemonic (str) – [a-zA-Z0-9_-.]* shortName (str) – [a-zA-Z0-9_-.]* configuration (str) – format:xml properties (dict) – information (str) – [sw{}$-().[]“‘_/,*+#:@!?;]* dependsOnID (int) – codeProfile (str) – [a-zA-Z0-9_-.]*
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 327, “limit”: 967, “responseCode”: 200, “count”: 664, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Candidate section policy.”, “messageTemplate”: “Past give west somebody main.”, “field”: “Value know this mean industry finally.”, “parameter”: {}, “timestamp”: 558035845}], “currentPage”: 760, “size”: 380}

`api.system.components.configuration.v1.template.` `view`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch configuration template (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of template to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 643, “limit”: 866, “responseCode”: 200, “count”: 391, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “We summer lot future system explain Mr chance.”, “messageTemplate”: “He environmental subject color wide.”, “field”: “Past become prevent easy.”, “parameter”: {}, “timestamp”: 9186035}], “currentPage”: 522, “size”: 962}

## Module contents